# Flask-Annex [![Travis][build-badge]][build] [![PyPI][pypi-badge]][pypi]
Efficient integration of external storage services for
[Flask](http://flask.pocoo.org/).

Run `pip install -e .[s3,tests]` to install for development and with `S3` support

[![Codecov][codecov-badge]][codecov]

[build-badge]: https://img.shields.io/travis/4Catalyzer/flask-annex/master.svg
[build]: https://travis-ci.org/4Catalyzer/flask-annex

[pypi-badge]: https://img.shields.io/pypi/v/Flask-Annex.svg
[pypi]: https://pypi.python.org/pypi/Flask-Annex

[codecov-badge]: https://img.shields.io/codecov/c/github/4Catalyzer/flask-annex/master.svg
[codecov]: https://codecov.io/gh/4Catalyzer/flask-annex
